@@ -1,18 +1,16 @@
 plot.uniah=function(x, lty=1, lcol=1, lwd=1, pch=19, pcol=1, pcex=0.7, main=NULL, ylab=NULL, xlab=NULL, lglab=NULL, lgloc=NULL, lgcex=0.9, ylim=NULL, xlim=NULL, ...){
-  y=x$psi
-  z=x$z
-  hr=exp(y)
-  
+  y=x$psi$psi
+  z=x$psi$z
+
   n=length(y)
-  y.obs=y[2:(n-1)] #first and last values are not petential jump points
-  hr.obs=hr[2:(n-1)]
+  y.obs=y[2:(n-1)] #first and last values are not potential jump points
   z.obs=z[2:(n-1)]
   
   if(is.null(main)) main=paste("Shape restricted additive hazards model\n(",x$shape," covariate effect)",sep="")
   if(is.null(xlab)) xlab=x$formula[[3]]
   if(is.null(xlim)) xlim=range(z)
   
-  if(is.null(lglab)) lglab="Potential jump point"
+  if(is.null(lglab)) lglab="Potential jump points"
   if(is.null(lgloc)){
     if(x$shape=='unimodal'){     lgloc='topleft'
     }else if(x$shape=='ushape'){ lgloc='topleft' 
